@@ -23,10 +23,13 @@
 
 #define OFONO_API_SUBJECT_TO_CHANGE
 
+void __ofono_exit();
+
 int __ofono_manager_init();
 void __ofono_manager_cleanup();
 
 const char **__ofono_modem_get_list();
+void __ofono_modem_shutdown();
 
 #include <ofono/log.h>
 
@@ -51,6 +54,8 @@ DBusMessage *__ofono_error_not_supported(DBusMessage *msg);
 DBusMessage *__ofono_error_timed_out(DBusMessage *msg);
 DBusMessage *__ofono_error_sim_not_ready(DBusMessage *msg);
 DBusMessage *__ofono_error_in_use(DBusMessage *msg);
+DBusMessage *__ofono_error_not_attached(DBusMessage *msg);
+DBusMessage *__ofono_error_attach_in_progress(DBusMessage *msg);
 
 void __ofono_dbus_pending_reply(DBusMessage **msg, DBusMessage *reply);
 
@@ -85,8 +90,9 @@ void __ofono_plugin_cleanup(void);
 
 #include <ofono/modem.h>
 
-unsigned int __ofono_modem_alloc_callid(struct ofono_modem *modem);
-void __ofono_modem_release_callid(struct ofono_modem *modem, int id);
+unsigned int __ofono_modem_callid_next(struct ofono_modem *modem);
+void __ofono_modem_callid_hold(struct ofono_modem *modem, int id);
+void __ofono_modem_callid_release(struct ofono_modem *modem, int id);
 
 struct ofono_atom;
 
